@@ -16,6 +16,8 @@ Path('abcde.zip', 'b/c.txt')
 True
 >>> (b / 'missing.txt').exists()
 False
+>>> str(c)
+'abcde.zip/b/c.txt'
 """
 
 from __future__ import division
@@ -26,15 +28,28 @@ import zipfile
 import operator
 import functools
 
+__metaclass__ = type
+
 
 class Path:
     __repr = '{self.__class__.__name__}({self.root.filename!r}, {self.at!r})'
 
     def __init__(self, root, at=''):
         self.root = root if isinstance(root, zipfile.ZipFile) \
-            else zipfile.ZipFile(root)
+            else zipfile.ZipFile(self._pathlib_compat(root))
         self.at = at
 
+    @staticmethod
+    def _pathlib_compat(path):
+        """
+        For path-like objects, convert to a filename for compatibility
+        on Python 3.6.1 and earlier.
+        """
+        try:
+            return path.__fspath__()
+        except AttributeError:
+            return str(path)
+
     @property
     def open(self):
         return functools.partial(self.root.open, self.at)
@@ -74,7 +89,7 @@ class Path:
         return filter(self._is_child, subs)
 
     def __str__(self):
-        return posixpath.join(self.root, self.at)
+        return posixpath.join(self.root.filename, self.at)
 
     def __repr__(self):
         return self.__repr.format(self=self)
